{% load static %}

{% if themes|length == 1 %}
{% for t in themes.values %}
{% for css in t %}
<link rel="stylesheet" type="text/css" href="{% static css %}">
{% endfor %}
{% endfor %}
{% elif theme %}
{% for css in theme %}
<link rel="stylesheet" type="text/css" href="{% static css %}">
{% endfor %}
{% else %}
<link
    rel="stylesheet"
    type="text/css"
    href="{% static 'admincolors/css/default.css' %}"
/>
{% endif %}
