{% extends "admin/base.html" %}
{% load admincolors i18n static %}

{% block title %}
{{ title }} | {{ site_title|default:_('Django site admin') }}
{% endblock %}

{% block blockbots %}
{{ block.super }}
{% colors_styles theme themes %}
{% endblock %}

{% block branding %}
<h1 id="site-name">
    <a href="{% url 'admin:index' %}">
        {{ site_header|default:_('Django administration') }}
    </a>
</h1>
{% endblock %}

{% block nav-global %}{% endblock %}

{% block footer %}
{{ block.super }}
{% colors_scripts %}
{% endblock %}
